@@ -16,6 +16,7 @@ sio = socketio.AsyncClient()
 
 loop = asyncio.get_event_loop()
 
+LOCAL_IP = [(s.connect(('8.8.8.8', 80)), s.getsockname()[0], s.close()) for s in [socket.socket(socket.AF_INET, socket.SOCK_DGRAM)]][0][1]
 
 def resolve_address(address):
     hostname = address.split("//")[-1:][0]
@@ -23,19 +24,10 @@ def resolve_address(address):
 
     return ip
 
-
-def get_local_ip():
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    s.connect(("8.8.8.8", 80))
-    ip = s.getsockname()[0]
-    s.close()
-
-    return ip
-
-
 @sio.on("connect")
 async def on_connect():
     print("connected to server")
+    await sio.emit(event="announce_ip", data=LOCAL_IP)
 
 
 @sio.on("in")
@@ -51,7 +43,7 @@ async def start_client(address):
 
     _toori.init(
         f"outbound && !loopback && ip && ip.DstAddr != {resolve_address(address)}",
-        get_local_ip(),
+        LOCAL_IP,
     )
 
     while True:
